@@ -50,7 +50,7 @@ namespace LongoMatch.Handlers
 	
 	/* Project Events */
 	public delegate void SaveProjectHandler(Project project, ProjectType projectType);
-	public delegate void OpenedProjectChangedHandler(Project project, ProjectType projectType);
+	public delegate void OpenedProjectChangedHandler(Project project, ProjectType projectType, PlaysFilter filter);
 	public delegate void OpenProjectHandler();
 	public delegate void CloseOpenendProjectHandler(bool save);
 	public delegate void NewProjectHandler();
@@ -64,6 +64,7 @@ namespace LongoMatch.Handlers
 	public delegate void ManageCategoriesHandler();
 	public delegate void ManageProjects();
 	public delegate void ManageDatabases();
+	public delegate void EditPreferences();
 	
 
 	/*Playlist Events*/
@@ -71,8 +72,6 @@ namespace LongoMatch.Handlers
 	public delegate void PlayListNodeAddedHandler(Play play);
 	/* A play list element is selected */
 	public delegate void PlayListNodeSelectedHandler(PlayListPlay play);
-	/* Save current playrate for a play list element */
-	public delegate void ApplyCurrentRateHandler(PlayListPlay play);
 	/* Open a playlist */
 	public delegate void OpenPlaylistHandler();
 	/* New a playlist */
