@@ -68,10 +68,11 @@ namespace LongoMatch.Interfaces.GUI
 		void OpenCategoriesTemplatesManager(ITemplatesService ts);
 		void OpenTeamsTemplatesManager(ITeamTemplatesProvider tp);
 		void OpenDatabasesManager(IDataBaseManager dm);
+		void OpenPreferencesEditor();
 		
 		void ManageJobs(IRenderingJobsManager manager);
 		
-		void TagPlay(Play play, TeamTemplate local, TeamTemplate visitor, bool showAllTags);
+		void TagPlay(Play play, Categories categories, TeamTemplate local, TeamTemplate visitor, bool showAllTags);
 		void DrawingTool(Image pixbuf, Play play, int stopTime);
 	}
 }
