@@ -31,6 +31,7 @@ using LongoMatch.Store.Templates;
 using LongoMatch.Gui.Dialog;
 using LongoMatch.Gui.Popup;
 using LongoMatch.Gui.Helpers;
+using Point = LongoMatch.Common.Point;
 
 namespace LongoMatch.Gui.Component
 {
@@ -55,6 +56,9 @@ namespace LongoMatch.Gui.Component
 			subcategoriestreeview1.SubCategorySelected += OnSubcategorySelected;
 			leadtimebutton.ValueChanged += OnLeadTimeChanged;;
 			lagtimebutton.ValueChanged += OnLagTimeChanged;
+			fieldcoordinatestagger.Background = Gdk.Pixbuf.LoadFromResource (Constants.FIELD_BACKGROUND);
+			goalcoordinatestagger.Background = Gdk.Pixbuf.LoadFromResource (Constants.GOAL_BACKGROUND);
+			halffieldcoordinatestagger.Background = Gdk.Pixbuf.LoadFromResource (Constants.HALF_FIELD_BACKGROUND);
 		}
 		
 		public bool CanChangeHotkey {
@@ -120,6 +124,8 @@ namespace LongoMatch.Gui.Component
 
 		private void  UpdateGui() {
 			ListStore list;
+			List<Coordinates> coords;
+			Coordinates c;
 			
 			if(cat == null)
 				return;
@@ -131,6 +137,38 @@ namespace LongoMatch.Gui.Component
 			colorbutton1.Color = Helpers.Misc.ToGdkColor(cat.Color);
 			sortmethodcombobox.Active = (int)cat.SortMethod;
 			
+			tagfieldcheckbutton.Active = cat.TagFieldPosition;
+			fieldcoordinatestagger.Visible = cat.TagFieldPosition;
+			coords = new List<Coordinates>();
+			c = new Coordinates();
+			c.Add (new Point (300, 300));
+			coords.Add (c);
+			if (cat.FieldPositionIsDistance) {
+				c.Add (new Point (400, 500));
+			}
+			fieldcoordinatestagger.Coordinates = coords;
+			trajectorycheckbutton.Active = cat.FieldPositionIsDistance;
+			
+			taghalffieldcheckbutton.Active = cat.TagHalfFieldPosition;
+			halffieldcoordinatestagger.Visible = cat.TagHalfFieldPosition;
+			coords = new List<Coordinates>();
+			c = new Coordinates();
+			c.Add (new Point (300, 300));
+			coords.Add (c);
+			if (cat.FieldPositionIsDistance) {
+				c.Add (new Point (400, 500));
+			}
+			halffieldcoordinatestagger.Coordinates = coords;
+			trajectoryhalfcheckbutton.Active = cat.HalfFieldPositionIsDistance;
+			
+			taggoalcheckbutton.Active = cat.TagGoalPosition;
+			coords = new List<Coordinates>();
+			c = new Coordinates();
+			c.Add (new Point (100, 100));
+			coords.Add (c);
+			goalcoordinatestagger.Coordinates = coords;
+			goalcoordinatestagger.Visible = cat.TagGoalPosition;
+			
 			if(cat.HotKey.Defined)
 				hotKeyLabel.Text = cat.HotKey.ToString();
 			else hotKeyLabel.Text = Catalog.GetString("none");
@@ -249,5 +287,57 @@ namespace LongoMatch.Gui.Component
 			subcatnameentry.Text = (model.GetValue(iter, 1) as ISubCategory).Name;
 			addbutton.Sensitive = true;
 		}
+		
+		protected void OnTaggoalcheckbuttonClicked (object sender, EventArgs e)
+		{
+			goalcoordinatestagger.Visible = taggoalcheckbutton.Active;
+			cat.TagGoalPosition = taggoalcheckbutton.Active;
+		}
+		
+		protected void OnTaghalffieldcheckbuttonClicked (object sender, EventArgs e)
+		{
+			halffieldcoordinatestagger.Visible = taghalffieldcheckbutton.Active;
+			cat.TagHalfFieldPosition = taghalffieldcheckbutton.Active;
+		}
+		
+		protected void OnTagfieldcheckbuttonClicked (object sender, EventArgs e)
+		{
+			fieldcoordinatestagger.Visible = tagfieldcheckbutton.Active;
+			cat.TagFieldPosition = tagfieldcheckbutton.Active;
+		}
+		
+		protected void OnTrajectoryhalffieldcheckbuttonClicked (object sender, EventArgs e)
+		{
+			List<Coordinates> coords;
+			Coordinates c;
+			
+			cat.HalfFieldPositionIsDistance = trajectoryhalfcheckbutton.Active;
+			
+			coords = new List<Coordinates>();
+			c = new Coordinates();
+			c.Add (new Point (300, 300));
+			coords.Add (c);
+			if (cat.HalfFieldPositionIsDistance) {
+				c.Add (new Point (400, 500));
+			}
+			halffieldcoordinatestagger.Coordinates = coords;
+		}
+		
+		protected void OnTrajectorycheckbuttonClicked (object sender, EventArgs e)
+		{
+			List<Coordinates> coords;
+			Coordinates c;
+			
+			cat.FieldPositionIsDistance = trajectorycheckbutton.Active;
+			
+			coords = new List<Coordinates>();
+			c = new Coordinates();
+			c.Add (new Point (300, 300));
+			coords.Add (c);
+			if (cat.FieldPositionIsDistance) {
+				c.Add (new Point (400, 500));
+			}
+			fieldcoordinatestagger.Coordinates = coords;
+		}
 	}
 }
