@@ -194,8 +194,8 @@ namespace LongoMatch.Gui
 				sd.Destroy();
 		}
 		
-		public void TagPlay (Play play, TeamTemplate local, TeamTemplate visitor, bool showAllTags) {
-			TaggerDialog tg = new TaggerDialog(play, local, visitor, showAllTags);
+		public void TagPlay (Play play, Categories categories, TeamTemplate local, TeamTemplate visitor, bool showAllTags) {
+			TaggerDialog tg = new TaggerDialog(play, categories, local, visitor, showAllTags);
 			tg.TransientFor = mainWindow as Gtk.Window;
 			tg.Run();
 			tg.Destroy();
@@ -248,6 +248,14 @@ namespace LongoMatch.Gui
 			pm.Show();
 		}
 		
+		public void OpenPreferencesEditor()
+		{
+			PropertiesEditor pe = new PropertiesEditor();
+			pe.TransientFor = mainWindow as Gtk.Window;
+			pe.Run();
+			pe.Destroy();
+		}
+		
 		public void OpenDatabasesManager(IDataBaseManager manager)
 		{
 			DatabasesManager dm = new DatabasesManager (manager);
@@ -326,6 +334,7 @@ namespace LongoMatch.Gui
 			int response = npd.Run();
 			while(true) {
 				if(response != (int)ResponseType.Ok) {
+					project = null;
 					break;
 				} else if(npd.Project == null) {
 					InfoMessage(Catalog.GetString("Please, select a video file."));
