@@ -84,7 +84,7 @@ namespace LongoMatch.Gui
 		public event ManageCategoriesHandler ManageCategoriesEvent;
 		public event ManageProjects ManageProjectsEvent;
 		public event ManageDatabases ManageDatabasesEvent;
-		public event ApplyCurrentRateHandler ApplyRateEvent;
+		public event EditPreferences EditPreferencesEvent;
 		
 		/* Game Units events */
 		public event GameUnitHandler GameUnitEvent;
@@ -273,22 +273,25 @@ namespace LongoMatch.Gui
 
 			/* Connect playlist events */
 			playlist.PlayListNodeSelected += EmitPlayListNodeSelected;
-			playlist.ApplyCurrentRate += EmitApplyRate;
 			playlist.NewPlaylistEvent += EmitNewPlaylist;
 			playlist.OpenPlaylistEvent += EmitOpenPlaylist;
 			playlist.SavePlaylistEvent += EmitSavePlaylist;
 
 			/* Connect PlayListNodeAdded events */
 			playsSelection.PlayListNodeAdded += OnPlayListNodeAdded;
+			timeline.PlayListNodeAdded += OnPlayListNodeAdded;
 
 			/* Connect tags events */
 			playsSelection.TagPlay += EmitTagPlay;
+			timeline.TagPlay += EmitTagPlay;
 
 			/* Connect SnapshotSeries events */
 			playsSelection.SnapshotSeries += EmitSnapshotSeries;
+			timeline.SnapshotSeries += EmitSnapshotSeries;
 
 			playlist.RenderPlaylistEvent += EmitRenderPlaylist;
 			playsSelection.RenderPlaylist += EmitRenderPlaylist;
+			timeline.RenderPlaylist += EmitRenderPlaylist;
 			
 			renderingstatebar1.ManageJobs += (e, o) => {EmitManageJobs();};
 			
@@ -315,6 +318,7 @@ namespace LongoMatch.Gui
 			TeamsTemplatesManagerAction.Activated += (o, e) => {EmitManageTeams();};
 			ProjectsManagerAction.Activated += (o, e) => {EmitManageProjects();};
 			DatabasesManagerAction.Activated +=  (o, e) => {EmitManageDatabases();};
+			PreferencesAction.Activated += (sender, e) => {EmitEditPreferences();};
 		}
 		
 		void DetachPlayer (bool detach) {
@@ -345,10 +349,12 @@ namespace LongoMatch.Gui
 					guTimeline.Visible = true;
 					gameunitstaggerwidget1.Visible = true;
 				}
+				videowidgetsbox.Visible = false;
 			} else {
 				ToggleAction action;
 				
 				Log.Debug("Attaching player again");
+				videowidgetsbox.Visible = true;
 				playercapturer.Reparent(this.videowidgetsbox);
 				playerWindow.Destroy();
 				
@@ -434,9 +440,9 @@ namespace LongoMatch.Gui
 			CloseProjectAction.Sensitive=sensitive;
 			TaggingViewAction.Sensitive = sensitive;
 			ManualTaggingViewAction.Sensitive = sensitive;
+			ExportProjectAction1.Sensitive = sensitive;
 			GameUnitsViewAction.Sensitive = sensitive2 && gameUnitsActionVisible;
 			TimelineViewAction.Sensitive = sensitive2;
-			ExportProjectAction1.Sensitive = sensitive2;
 			HideAllWidgetsAction.Sensitive=sensitive2;
 			SaveProjectAction.Sensitive = sensitive2;
 		}
@@ -746,6 +752,13 @@ namespace LongoMatch.Gui
 		#endregion
 		
 		#region Events
+		
+		private void EmitEditPreferences ()
+		{
+			if (EditPreferencesEvent != null)
+				EditPreferencesEvent();
+		}
+		
 		private void EmitPlaySelected(Play play)
 		{
 			if (PlaySelectedEvent != null)
@@ -812,11 +825,6 @@ namespace LongoMatch.Gui
 				RenderPlaylistEvent(playlist);
 		}
 		
-		private void EmitApplyRate(PlayListPlay plNode) {
-			if (ApplyRateEvent != null)
-				ApplyRateEvent (plNode);
-		}
-
 		private void EmitTagPlay(Play play) {
 			if (TagPlayEvent != null)
 				TagPlayEvent (play);
