@@ -49,14 +49,19 @@ namespace LongoMatch.Services
 
 			SetupBaseDir();
 
-			/* Init internationalization support */
-			Catalog.Init(Constants.SOFTWARE_NAME.ToLower(),Config.RelativeToPrefix("share/locale"));
-
 			/* Check default folders */
 			CheckDirs();
 			
 			/* Load user config */
 			Config.Load();
+			
+			if (Config.Lang != null) {
+				Environment.SetEnvironmentVariable ("LANGUAGE", Config.Lang);
+			}
+			
+			/* Init internationalization support */
+			Catalog.Init(Constants.SOFTWARE_NAME.ToLower(),Config.RelativeToPrefix("share/locale"));
+
 		}
 
 		public static void Start(IGUIToolkit guiToolkit, IMultimediaToolkit multimediaToolkit) {
@@ -77,16 +82,20 @@ namespace LongoMatch.Services
 			dbManager = new DataBaseManager (Config.DBDir, guiToolkit);
 			dbManager.SetActiveByName (Config.CurrentDatabase);
 			
+			/* Start Migration */
+			MigrationsManager migration = new MigrationsManager(ts, dbManager);
+			migration.StartMigration();
+			
+			/* Start the rendering jobs manager */
+			videoRenderer = new RenderingJobsManager(multimediaToolkit, guiToolkit);
+			
 			/* Start the events manager */
-			eManager = new EventsManager(guiToolkit);
-
+			eManager = new EventsManager(guiToolkit, videoRenderer);
+			
 			/* Start the hotkeys manager */
 			hkManager = new HotKeysManager(guiToolkit.MainWindow);
 			hkManager.newMarkEvent += eManager.OnNewTag;
 
-			/* Start the rendering jobs manager */
-			videoRenderer = new RenderingJobsManager(multimediaToolkit, guiToolkit);
-			
 			/* Start Game Units manager */
 			guManager = new GameUnitsManager(mainWindow, mainWindow.Player);
 			
@@ -98,13 +107,7 @@ namespace LongoMatch.Services
 		}
 
 		public static void BindEvents(IMainWindow mainWindow) {
-			/* Connect player events */
-			/* FIXME:
-			player.Prev += OnPrev;
-			player.Next += OnNext;
-			player.Tick += OnTick;
-			player.SegmentClosedEvent += OnSegmentClosedEvent;
-			player.DrawFrame += OnDrawFrame;*/
+			mainWindow.EditPreferencesEvent += () => {guiToolkit.OpenPreferencesEditor();};
 		}
 
 		public static void CheckDirs() {
@@ -142,15 +145,15 @@ namespace LongoMatch.Services
 			}
 		}
 		
-		private static void OnOpenedProjectChanged (Project project, ProjectType projectType) {
+		private static void OnOpenedProjectChanged (Project project, ProjectType projectType,
+		                                            PlaysFilter filter) {
 			if (project != null) {
 				hkManager.Categories=project.Categories;
 			} else {
 				hkManager.Categories=null;
 			}
 			
-			eManager.OpenedProject = project;
-			eManager.OpenedProjectType = projectType;
+			eManager.SetProject (project, projectType, filter);
 			guManager.OpenedProject = project;
 			plManager.OpenedProject = project;
 			dbManager.OpenedProject = project;
