@@ -24,6 +24,7 @@ using System.IO;
 using System.Linq;
 using Db4objects.Db4o;
 using Db4objects.Db4o.Query;
+using Db4objects.Db4o.Ext;
 
 using LongoMatch.Common;
 using LongoMatch.Interfaces;
@@ -46,8 +47,6 @@ namespace LongoMatch.DB
 		Version dbVersion;
 		BackupDate lastBackup;
 		int count;
-		const int MAYOR=2;
-		const int MINOR=0;
 		TimeSpan maxDaysWithoutBackup = new TimeSpan(5, 0, 0, 0);
 		
 		
@@ -72,6 +71,9 @@ namespace LongoMatch.DB
 			get {
 				return dbVersion;
 			}
+			set {
+				UpdateVersion (value);
+			}
 		}
 		
 		public string Name {
@@ -101,6 +103,7 @@ namespace LongoMatch.DB
 				File.Delete (DBFile);
 				return true;
 			} catch (Exception ex) {
+				Log.Exception (ex);
 				return false;
 			}
 		}
@@ -135,25 +138,31 @@ namespace LongoMatch.DB
 		public bool Load() {
 			bool ret = false;
 			
-			Log.Debug ("Loading database file: " + DBFile);
-			/* Create a new DB if it doesn't exists yet */
-			if(!System.IO.File.Exists(DBFile)) {
-				Log.Debug ("File doesn't exists, creating a new one");
-				CreateNewDB();
-				ret = true;
-			}
-			
-			GetDBVersion();
-			GetBackupDate();
-			CheckDB();
 			try {
-				BackupDB();
-			} catch (Exception e) {
-				Log.Error("Error creating database backup");
-				Log.Exception(e);
+				Log.Debug ("Loading database file: " + DBFile);
+				/* Create a new DB if it doesn't exists yet */
+				if(!System.IO.File.Exists(DBFile)) {
+					Log.Debug ("File doesn't exists, creating a new one");
+					CreateNewDB();
+					ret = true;
+				}
+				
+				GetDBVersion();
+				GetBackupDate();
+				CheckDB();
+				try {
+					BackupDB();
+				} catch (Exception e) {
+					Log.Error("Error creating database backup");
+					Log.Exception(e);
+				}
+				count = GetAllProjects().Count;
+				ListObjects();
+			} catch (DatabaseFileLockedException locked) {
+				throw new DBLockedException (locked);
+			} catch (Db4oException ex) {
+				throw new UnknownDBErrorException (ex);
 			}
-			count = GetAllProjects().Count;
-			ListObjects();
 			return ret;
 		}
 		
@@ -339,7 +348,7 @@ namespace LongoMatch.DB
 			// Create new DB and add version and last backup date
 			IObjectContainer db = Db4oFactory.OpenFile(DBFile);
 			try {
-				dbVersion= new Version(MAYOR,MINOR);
+				dbVersion= new Version(Constants.DB_MAYOR_VERSION, Constants.DB_MINOR_VERSION);
 				lastBackup = new BackupDate { Date = DateTime.UtcNow};
 				db.Store(dbVersion);
 				db.Store(lastBackup);
@@ -353,7 +362,7 @@ namespace LongoMatch.DB
 		private void GetDBVersion () {
 			dbVersion = GetObject<Version>();
 			if (dbVersion == null)
-				dbVersion = new Version(MAYOR, MINOR);
+				dbVersion = new Version(Constants.DB_MAYOR_VERSION, Constants.DB_MINOR_VERSION);
 			Log.Information("DB version: "+ dbVersion.ToString());
 		}
 		
@@ -382,6 +391,23 @@ namespace LongoMatch.DB
 			}
 		}
 		
+		private void UpdateVersion (Version version) {
+			IObjectContainer db = Db4oFactory.OpenFile(DBFile);
+			try	{
+				IQuery query = db.Query();
+				query.Constrain(typeof(Version));
+				IObjectSet result = query.Execute();
+				while (result.HasNext()) {
+					Version v = result.Next() as Version;
+					db.Delete (v);
+				}
+				db.Store(version);
+				dbVersion = version;
+			} finally {
+				db.Close();
+			}
+		}
+		
 		private T GetObject<T>() {
 			T ret = default(T);
 			IObjectContainer db = Db4oFactory.OpenFile(DBFile);
