@@ -26,6 +26,7 @@ using LongoMatch.Interfaces;
 using LongoMatch.Interfaces.GUI;
 using LongoMatch.Store;
 using Mono.Unix;
+using System.IO;
 
 namespace LongoMatch.Services
 {
@@ -42,15 +43,18 @@ namespace LongoMatch.Services
 		Project openedProject;
 		ProjectType projectType;
 		Time startTime;
+		PlaysFilter filter;
 		
 		IGUIToolkit guiToolkit;
 		IMainWindow mainWindow;
 		IPlayer player;
 		ICapturer capturer;
+		IRenderingJobsManager renderer;
 
-		public EventsManager(IGUIToolkit guiToolkit)
+		public EventsManager(IGUIToolkit guiToolkit, IRenderingJobsManager renderer)
 		{
 			this.guiToolkit = guiToolkit;
+			this.renderer = renderer;
 			mainWindow = guiToolkit.MainWindow;
 			player = mainWindow.Player;
 			capturer = mainWindow.Capturer;
@@ -58,16 +62,18 @@ namespace LongoMatch.Services
 			ConnectSignals();
 		}
 
-		public  Project OpenedProject {
-			set {
-				openedProject = value;
+		void Save (Project project) {
+			if (Config.AutoSave) {
+				Core.DB.UpdateProject (project);
 			}
 		}
-
-		public ProjectType OpenedProjectType {
-			set {
-				projectType = value;
-			}
+		
+		public void SetProject (Project project, ProjectType projectType,
+		                        PlaysFilter filter)
+		{
+			this.filter = filter;
+			this.openedProject = project;
+			this.projectType = projectType;
 		}
 
 		private void ConnectSignals() {
@@ -95,8 +101,38 @@ namespace LongoMatch.Services
 			player.Prev += OnPrev;
 			player.SegmentClosedEvent += OnSegmentClosedEvent;
 			player.DrawFrame += OnDrawFrame;
+			player.PlaybackRateChanged += HandlePlaybackRateChanged;
 		}
 
+		void RenderPlay (Project project, Play play, MediaFile file) {
+			PlayList playlist;
+			EncodingSettings settings;
+			EditionJob job;
+			string outputDir, outputFile;
+			
+			if (Config.AutoRenderDir == null ||
+			    !Directory.Exists (Config.AutoRenderDir)) {
+				outputDir = Config.VideosDir;
+			} else {
+				outputDir = Config.AutoRenderDir;
+			}
+			
+			outputFile = String.Format ("{0}-{0}.mp4", play.Category.Name, play.Name);
+			outputFile = Path.Combine (outputDir, project.Description.Title, outputFile);
+			try {
+				Directory.CreateDirectory (Path.GetDirectoryName (outputFile));
+				settings = EncodingSettings.DefaultRenderingSettings (outputFile);
+				playlist = new PlayList();
+				playlist.Add (new PlayListPlay (play, file, true));
+			
+				job = new EditionJob (playlist, settings, Config.EnableAudio, Config.OverlayTitle); 
+				renderer.AddJob (job);
+			} catch (Exception ex) {
+				Log.Exception (ex);
+			}
+			
+		}
+		
 		private void ProcessNewTag(Category category,Time pos) {
 			Time length, startTime, stopTime, start, stop, fStart, fStop;
 
@@ -149,9 +185,18 @@ namespace LongoMatch.Services
 			if (!Config.FastTagging)
 				LaunchPlayTagger(play, false);
 			mainWindow.AddPlay(play);
+			filter.Update();
 			if (projectType == ProjectType.FileProject) {
 				player.Play();
 			}
+			Save (openedProject);
+			
+			if (projectType == ProjectType.CaptureProject ||
+			    projectType == ProjectType.URICaptureProject) {
+			    if (Config.AutoRenderPlaysInLive) {
+					RenderPlay (openedProject, play, openedProject.Description.File);
+				}
+			}
 		}
 
 		protected virtual void OnNewTagAtFrame(Category category, int frame) {
@@ -202,15 +247,24 @@ namespace LongoMatch.Services
 		}
 
 		private void LaunchPlayTagger(Play play, bool showAllTags) {
-			guiToolkit.TagPlay(play, openedProject.LocalTeamTemplate,
-			                   openedProject.VisitorTeamTemplate, showAllTags);
+			guiToolkit.TagPlay(play, openedProject.Categories,
+			                   openedProject.LocalTeamTemplate,
+			                   openedProject.VisitorTeamTemplate,
+			                   showAllTags);
+		}
+
+		void HandlePlaybackRateChanged (float rate)
+		{
+			if (selectedTimeNode != null) {
+				selectedTimeNode.Rate = rate;
+			}
 		}
 
 		protected virtual void OnPlaySelected(Play play)
 		{
 			Log.Debug("Play selected: " + play);
 			selectedTimeNode = play;
-			player.SetStartStop(play.Start.MSeconds,play.Stop.MSeconds);
+			player.SetStartStop(play.Start.MSeconds,play.Stop.MSeconds, play.Rate);
 			drawingManager.Play=play;
 			mainWindow.UpdateSelectedPlay(play);
 		}
@@ -232,6 +286,7 @@ namespace LongoMatch.Services
 			else if(tNode is Category) {
 				mainWindow.UpdateCategories(openedProject.Categories);
 			}
+			filter.Update();
 		}
 
 		protected virtual void OnPlaysDeleted(List<Play> plays)
@@ -242,8 +297,9 @@ namespace LongoMatch.Services
 
 			if(projectType == ProjectType.FileProject) {
 				player.CloseActualSegment();
-				Core.DB.UpdateProject(openedProject);
+				Save (openedProject);
 			}
+			filter.Update();
 		}
 
 		protected virtual void OnSegmentClosedEvent()
@@ -286,7 +342,7 @@ namespace LongoMatch.Services
 			newplay.Notes = play.Notes;
 			newplay.Drawings = play.Drawings;
 			mainWindow.AddPlay(newplay);
-			Core.DB.UpdateProject (openedProject);
+			Save (openedProject);
 		}
 	}
 }
